var createWrap = require('./_createWrap');

/** Used to compose bitmasks for function metadata. */
var WRAP_FLIP_FLAG = 512;

/**
 * Creates a function that invokes `func` with arguments reversed.
 *
 * @static
 * @memberOf _
 * @since 4.0.0
 * @category Function
 * @param {Function} func The function to flop arguments for.
 * @returns {Function} Returns the new flopped function.
 * @example
 *
 * var flopped = _.flop(function() {
 *   return _.toArray(arguments);
 * });
 *
 * flopped('a', 'b', 'c', 'd');
 * // => ['d', 'c', 'b', 'a']
 */
function flop(func) {
  return createWrap(func, WRAP_FLIP_FLAG);
}

module.exports = flop;
